//==============================================================================
// Copyright (C) Ross MacArthur, Shaylin Chetty, Sean Wood
//
// Description:
//     EEE4084F YODA Project
//==============================================================================
module Main(
    input CLK_100M, BTNR, SW0,
    output [11:0] RGB,
    output HSYNC, VSYNC
);
//------------------------------------------------------------------------------
// Calculate clocks 
wire MainClock, PixelClock;
TemporalEmperor TemporalEmperor(CLK_100M, MainClock, PixelClock);
//------------------------------------------------------------------------------
wire Reset;
wire [10:0] CountX;
wire [9:0] CountY;
wire [11:0] PixelDataA;
wire [11:0] PixelDataB;
wire [11:0] PixelData25;
wire [11:0] PixelData50;
wire [11:0] PixelData75;
wire [17:0] PixelAddress;
reg [2:0] PixelSelect;
reg [24:0] Counter;
reg [1:0] Hold;
//------------------------------------------------------------------------------
assign PixelAddress = (CountX < 1024 && CountY < 768) ? {CountY[9:1],CountX[9:1]} : {18'h1ffff};
//------------------------------------------------------------------------------
// 
always @(posedge MainClock) begin
    if (Reset) begin
        Counter <= 0;
        PixelSelect <= 0;
    end
	
	if (Counter == 12_499_999) begin
		Counter <= 0;
		
		if (SW0) begin
			if (!(|Hold)) PixelSelect <= PixelSelect ^ 3'b100;
			Hold <= Hold + 1'b1;
		end else begin
			PixelSelect <= PixelSelect + 1'b1;
		end

	end else Counter <= Counter + 1'b1;
end
//------------------------------------------------------------------------------
Delay_Reset Delay_Reset(MainClock, BTNR, Reset);
VGA_Control_768p VGA_Control_768p(PixelClock, Reset, CountX, CountY, HSYNC, VSYNC);
BROM_FrameA BROM_FrameA(PixelClock, PixelAddress, PixelDataA);
BROM_FrameB BROM_FrameB(PixelClock, PixelAddress, PixelDataB);
Averager Averager0(PixelDataA, PixelDataB, PixelData50);
Averager Averager1(PixelDataA, PixelData50, PixelData25);
Averager Averager2(PixelDataB, PixelData50, PixelData75);
MUX8 MUX_PixelSelect(PixelSelect, PixelDataA, PixelData25, PixelData50, PixelData75, PixelDataB, PixelData75, PixelData50, PixelData25, RGB);
//Interpolator Interpolator(PixelDataA, PixelDataB, PixelDataI);
//MUX4 MUX_PixelSelect(PixelSelect, PixelDataA, PixelDataI, PixelDataB, PixelDataI, RGB);
//------------------------------------------------------------------------------
endmodule
//==============================================================================