//==============================================================================
// Copyright (C) Ross MacArthur, Shaylin Chetty, Sean Wood
//
// Author: Ross MacArthur
// Description:
//     EEE4084F YODA Project: VGA control
//     We are in the display area when CountX < 640 and CountY < 480
// Sources:
//     http://sdrg.ee.uct.ac.za/Bootcamp/Memo/Day5.zip
//     http://tinyvga.com/vga-timing/640x480@60Hz
//     https://learn.digilentinc.com/Documents/269
//     http://www-mtl.mit.edu/Courses/6.111/labkit/images/vga_line.png
//     http://www.ece.utah.edu/~kalla/ECE3710/Nexys3_VGA_Tutorial.pdf
//==============================================================================
module VGA_Control_480p(
    input CLK_25M, Reset,
    output reg [9:0] CountX, // Current X position on screen
    output reg [8:0] CountY, // Current Y position on screen
    output reg HSYNC, VSYNC  // Sync clocks for screen
);
//------------------------------------------------------------------------------
always @(posedge CLK_25M) begin
    // Reset operation ----------------------------------------------------------
    if(Reset) begin
        CountX <= 0; 
        CountY <= 0;
        HSYNC <= 1; 
        VSYNC <= 1;
    end
    // Normal operation ---------------------------------------------------------
    else begin
        // Counters at frequencies as close to 31.46875 kHz and 60 Hz as possible
		  // Count higher than the display area so that it includes front porch,
		  // back porch and sync pulse time
        if (CountX == 799) begin            
            CountX <= 0;
            if (CountY == 524) CountY <= 0; 
            else CountY <= CountY + 1'b1;
        end 
        else CountX <= CountX + 1'b1;
        // Pulse horizontal syncs
        if      (CountX == 655) HSYNC <= 0; // Start sync-pulse of 96
        else if (CountX == 751) HSYNC <= 1; // End sync-pulse of 96
        // Pulse verticle syncs 
        if      (CountY == 489) VSYNC <= 0; // Start sync-pulse of 2
        else if (CountY == 491) VSYNC <= 1; // End sync-pulse of 2
    end
end
//------------------------------------------------------------------------------
endmodule
//==============================================================================